searchNodes=[{"doc":"Functions for validating keyword lists. The main function in this module is validate/2 , which allows developers to validate a keyword list against a given schema. A schema is a keyword list that matches the keys for the keyword list. The values in the schema represent the options available during validation. iex&gt; KeywordValidator . validate ( [ foo : :bar ] , [ foo : [ is : :atom ] ] ) { :ok , [ foo : :bar ] } iex&gt; KeywordValidator . validate ( [ foo : :bar ] , [ foo : [ is : :integer ] ] ) { :error , [ foo : [ &quot;must be an integer&quot; ] ] }","ref":"KeywordValidator.html","title":"KeywordValidator","type":"module"},{"doc":"Builds documentation for a given schema. This can be used to inject documentation in your docstrings. For example: @options_schema KeywordValidator . schema! ( [ key : [ type : :any , doc : &quot;Some option.&quot; ] ] ) @doc &quot;Options: \\n \#{ KeywordValidator . docs ( @options_schema ) } &quot; This will automatically generate documentation that includes information on required keys and default values.","ref":"KeywordValidator.html#docs/1","title":"KeywordValidator.docs/1","type":"function"},{"doc":"Prepares a schema or raises an ArgumentError exception if invalid. A schema is a keyword list of keys and value options. This is the preferred method of providing a validation schema as it ensures your schema is valid and avoids running additional validation on each invocation. You can then declare your schema as a module attribute: @opts_schema KeywordValidator . schema! ( [ ... ] ) KeywordValidator . validate! ( keyword , @opts_schema ) Value Options :is - The value type associated with the key. Must be one of KeywordValidator.value_is/0 . Defaults to :any . :default - The default value for the key if not provided one. :required - Boolean representing whether the key is required or not. Defaults to false . :custom - A list of two-arity functions or tuples in the format {module, function} that serve as custom validators. The function will be given the key and value as arguments, and must return a list of string errors (or an empty list if no errors are present). Defaults to [] . :doc - Documentation for the option. Defaults to false . Is Options The following value types are available for use with the :is option: {:=, value} - Equal to value. :any - Any value. :atom - An atom. :binary - A binary. :bitstring - A bitstring. :boolean - A boolean. :float - A float. :fun - A function. {:fun, arity} - A function with specified arity. {:in, [value]} - In the list of values. :integer - An integer. :keyword - A keyword list. {:keyword, schema} - A keyword with the provided schema. :list - A list. :map - A map. :mfa - A module, function and args. :mod_args - A module and args. :mod_fun - A module and function. :mod - A module. :number - A number. {:one_of, [type]} - Any one of the provided types. :pid - A PID. :port - A port. :struct - A struct. {:struct, type} - A struct of the provided type. :timeout - A timeout (integer or :infinite ). :tuple - A tuple. {:tuple, size} - A tuple of the provided size. {:tuple, tuple} - A tuple with the provided tuple types.","ref":"KeywordValidator.html#schema!/1","title":"KeywordValidator.schema!/1","type":"function"},{"doc":"The same as validate/2 but raises an ArgumentError exception if invalid. Example iex&gt; KeywordValidator . validate! ( [ foo : :bar ] , [ foo : [ is : :atom , required : true ] ] ) [ foo : :foo ] iex&gt; KeywordValidator . validate! ( [ foo : &quot;bar&quot; ] , [ foo : [ is : :atom , required : true ] ] ) ** (ArgumentError) Invalid keyword given. Keyword : [ foo : &quot;bar&quot; ] Invalid : foo : [ &quot;must be an atom&quot; ]","ref":"KeywordValidator.html#validate!/3","title":"KeywordValidator.validate!/3","type":"function"},{"doc":"Validates a keyword list using the provided schema. A schema is a keyword list (or prepared schema via schema!/1 ) - with each key representing a key in your keyword list. The values in the schema keyword list represent the options available for validation. If the validation passes, we are returned a two-item tuple of {:ok, keyword} . Otherwise, returns {:error, invalid} - where invalid is a keyword list of errors. Schema Please see schema!/1 for options available when building schemas. Options :strict - Boolean representing whether extra keys will become errors. Defaults to true . Examples iex&gt; KeywordValidator . validate ( [ foo : :foo ] , [ foo : [ is : :atom , required : true ] ] ) { :ok , [ foo : :foo ] } iex&gt; KeywordValidator . validate ( [ foo : :foo ] , [ bar : [ is : :any ] ] ) { :error , [ foo : [ &quot;is not a valid key&quot; ] ] } iex&gt; KeywordValidator . validate ( [ foo : :foo ] , [ bar : [ is : :any ] ] , strict : false ) { :ok , [ ] } iex&gt; KeywordValidator . validate ( [ foo : :foo ] , [ foo : [ is : { :in , [ :one , :two ] } ] ] ) { :error , [ foo : [ &quot;must be one of: [:one, :two]&quot; ] ] } iex&gt; KeywordValidator . validate ( [ foo : { :foo , 1 } ] , [ foo : [ is : { :tuple , { :atom , :integer } } ] ] ) { :ok , [ foo : { :foo , 1 } ] } iex&gt; KeywordValidator . validate ( [ foo : [ &quot;one&quot; , 2 ] ] , [ foo : [ is : { :list , :binary } ] ] ) { :error , [ foo : [ &quot;must be a list of type :binary&quot; ] ] } iex&gt; KeywordValidator . validate ( [ foo : % Foo { } ] , [ foo : [ is : { :struct , Bar } ] ] ) { :error , [ foo : [ &quot;must be a struct of type Bar&quot; ] ] } iex&gt; KeywordValidator . validate ( [ foo : &quot;foo&quot; ] , [ foo : [ is : :any , custom : [ fn key , val -&gt; [ &quot;some error&quot; ] end ] ] ] ) { :error , [ foo : [ &quot;some error&quot; ] ] }","ref":"KeywordValidator.html#validate/3","title":"KeywordValidator.validate/3","type":"function"},{"doc":"A keyword base schema.","ref":"KeywordValidator.html#t:base_schema/0","title":"KeywordValidator.base_schema/0","type":"type"},{"doc":"Custom validation logic for key values.","ref":"KeywordValidator.html#t:custom_validator/0","title":"KeywordValidator.custom_validator/0","type":"type"},{"doc":"An invalid keyword key.","ref":"KeywordValidator.html#t:invalid/0","title":"KeywordValidator.invalid/0","type":"type"},{"doc":"Individual validation options.","ref":"KeywordValidator.html#t:option/0","title":"KeywordValidator.option/0","type":"type"},{"doc":"All validation options.","ref":"KeywordValidator.html#t:options/0","title":"KeywordValidator.options/0","type":"type"},{"doc":"A keyword schema.","ref":"KeywordValidator.html#t:schema/0","title":"KeywordValidator.schema/0","type":"type"},{"doc":"Various value :is options.","ref":"KeywordValidator.html#t:value_is/0","title":"KeywordValidator.value_is/0","type":"type"},{"doc":"Individual value options.","ref":"KeywordValidator.html#t:value_opt/0","title":"KeywordValidator.value_opt/0","type":"type"},{"doc":"All value options.","ref":"KeywordValidator.html#t:value_opts/0","title":"KeywordValidator.value_opts/0","type":"type"},{"doc":"KeywordValidator provides a simple interface to validate keyword lists in Elixir.","ref":"readme.html","title":"KeywordValidator","type":"extras"},{"doc":"The package can be installed by adding keyword_validator to your list of dependencies in mix.exs : def deps do [ { :keyword_validator , &quot;~&gt; 2.0&quot; } ] end","ref":"readme.html#installation","title":"KeywordValidator - Installation","type":"extras"},{"doc":"Please see HexDocs for additional documentation.","ref":"readme.html#documentation","title":"KeywordValidator - Documentation","type":"extras"},{"doc":"To begin validating, we must first create a schema that defines the rules for our keyword list. A schema is a simple keyword list with each value representing the options available for validation. If the validation passes, we are returned a valid keyword list. iex&gt; keyword = [ foo : :foo , bar : &quot;one&quot; ] iex&gt; schema = [ foo : [ is : :atom , required : true ] , bar : [ is : { :in , [ &quot;one&quot; , &quot;two&quot; , &quot;three&quot; ] } ] ] iex&gt; KeywordValidator . validate ( keyword , schema ) { :ok , [ foo : :foo , bar : &quot;one&quot; ] } To avoid additional schema validation - define your schemas as module attributes. @opts_schema KeywordValidator . schema! ( [ foo : [ is : :integer ] ] ) If validation fails on any of the keys, a keyword list of the invalid entries and the associated errors is returned. iex&gt; keyword = [ foo : &quot;foo&quot; , bar : &quot;bar&quot; ] iex&gt; schema = [ foo : [ is : :atom , required : true ] , bar : [ is : { :in , [ &quot;one&quot; , &quot;two&quot; , &quot;three&quot; ] } ] ] iex&gt; KeywordValidator . validate ( keyword , schema ) { :error , [ bar : [ &quot;must be one of: [ \\&quot; one \\&quot; , \\&quot; two \\&quot; , \\&quot; three \\&quot; ]&quot; ] , foo : [ &quot;must be a binary&quot; ] ] } We can optionally use the KeywordValidator.validate!/2 function as well - which will raise an error that describes the invalid key entries. ** (ArgumentError) Invalid keyword given. Keyword : [ foo : :foo , bar : :bar ] Invalid : bar : [ &quot;must be one of: [:one, :two, :three]&quot; ] foo : [ &quot;must be a binary&quot; ] To view all the available validation options, please check out the relevant documentation . You can optionally generate documentation from your schemas. @doc &quot;&quot;&quot; This is a function. ## Options \#{ KeywordValidator . docs ( @opts_schema ) } &quot;&quot;&quot; def my_function ( opts ) do ... end","ref":"readme.html#getting-started","title":"KeywordValidator - Getting Started","type":"extras"}]